@@ -2,8 +2,9 @@
 #
 # SPDX-License-Identifier: EUPL-1.2
 
-__version__ = "0.10.10"
+__version__ = "0.10.17"
 
+from minty_pyramid.generic_loader import GenericEngine
 from minty_pyramid.loader import Engine
 
-__all__ = ["Engine"]
+__all__ = ["Engine", "GenericEngine"]
