@@ -5,6 +5,7 @@
 import datetime
 import os
 from jinja2 import Environment, PackageLoader
+from typing import Dict, List
 
 
 def load_template(template_name: str):
@@ -99,7 +100,7 @@ def group_routes_by(routes: list, param: str) -> dict:
     :return: grouped routes
     :rtype: dict
     """
-    grouped_routes = {}
+    grouped_routes: Dict[str, List] = {}
     for route in routes:
         grouped_by_param = grouped_routes.get(route[param], [])
         grouped_by_param.append(route)
