@@ -10,29 +10,16 @@ from .exception_handlers import (
     exception_cqrs_not_found,
     exception_cqrs_validation,
 )
+from .generic_loader import GenericEngine, log_record_factory
 from .session_manager import SessionRetriever, session_manager_factory
-from minty import Base
 from minty.cqrs import CQRS
 from minty.infrastructure import InfrastructureFactory
-from minty.logging.mdc import get_mdc, mdc
 from minty_pyramid.renderer import jsonapi
 from pyramid.config import Configurator
-from pyramid.events import NewResponse, subscriber
 from uuid import uuid4
 
 
-@subscriber(NewResponse)
-def new_response_callback(event):
-    """Set default headers when a new response is created"""
-    if not event.response.headers.get("cache-control"):
-        event.response.headers.update({"cache-control": "no-store"})
-
-    event.response.headers.update(
-        {"request-id": str(event.request.request_id)}
-    )
-
-
-class Engine(Base):
+class Engine(GenericEngine):
     """Pyramid configurator."""
 
     __slots__ = [
@@ -134,27 +121,18 @@ class Engine(Base):
         config.add_view(view=exception_cqrs_validation, name="validation")
         config.add_view(view=exception_cqrs_catch_all, name="catch_all")
 
-        config.add_tween("minty_pyramid.loader.RequestTimer")
-        config.add_tween("minty_pyramid.loader.RequestDataLogger")
+        config.add_tween("minty_pyramid.generic_loader.RequestTimer")
+        config.add_tween("minty_pyramid.generic_loader.RequestDataLogger")
+
+        config.add_subscriber(
+            "minty_pyramid.generic_loader.new_response_callback",
+            "pyramid.events.NewResponse",
+        )
 
         config.scan()
         self.config = config
         return config
 
-    def main(self) -> object:
-        """Run the application by calling the wsgi_app function of Pyramid.
-
-        :raises ValueError: When setup is forgotten
-        :return: wsgi app
-        :rtype: object
-        """
-        if self.config is None:
-            raise ValueError("Make sure you run setup before 'main'")
-
-        self.logger.info("Creating WSGI application")
-
-        return self.config.make_wsgi_app()
-
 
 def _build_cqrs_setup(cqrs):
     """Create a callable for setting up the "CQRS" methods request objects.
@@ -250,85 +228,7 @@ def _build_http_session_manager(
     return setup_session_request
 
 
-class RequestTimer(Base):
-    """Middleware / tween to log request time and count to statsd."""
-
-    def __init__(self, handler, registry):
-        self.handler = handler
-        self.registry = registry
-
-    def __call__(self, request):
-        """Log time and count to statsd before and after execution of handler.
-
-        :param request: request
-        :type request: class
-        :return: response
-        :rtype: class
-        """
-        timer = self.statsd.get_timer()
-        timer.start()
-
-        response = self.handler(request)
-
-        try:
-            req_name = request.matched_route.name
-        except AttributeError:
-            req_name = "unknown"
-
-        timer.stop(f"{req_name}.time")
-
-        self.statsd.get_counter().increment(
-            f"{req_name}.{response.status_int}.count"
-        )
-
-        return response
-
-
-def get_logging_info(request):
-    logging_info = {}
-
-    logging_info["hostname"] = request.host
-    logging_info["request_id"] = request.request_id
-    logging_info["action_path"] = request.path_info
-
-    # Log the instance_hostname for this configuration, if available;
-    # otherwise the hostname used by the user is used.
-    logging_info["instance_hostname"] = request.configuration.get(
-        "instance_hostname", request.host
-    )
-
-    try:
-        logging_info["session_id"] = request.session_id
-    except AttributeError:
-        logging_info["session_id"] = "<sessions not configured>"
-
-    return logging_info
-
-
-class RequestDataLogger(Base):
-    """Tween to add request-specific information to log entries"""
-
-    def __init__(self, handler, registry):
-        self.handler = handler
-        self.registry = registry
-
-    def __call__(self, request):
-        logging_info = get_logging_info(request)
-        with mdc(**logging_info):
-            response = self.handler(request)
-
-        return response
-
-
 # Add a "req" key, containing the MDC to logging output in minty-pyramid
 # applications.
 old_factory = logging.getLogRecordFactory()
-
-
-def log_record_factory(*args, **kwargs):
-    record = old_factory(*args, **kwargs)
-    record.req = get_mdc()
-    return record
-
-
 logging.setLogRecordFactory(log_record_factory)
