@@ -286,6 +286,12 @@ class JSONAPIEntityView:
                         continue
                     params[v] = self.request.json_body[k]
 
+        if "paging" in calldata:
+            paging_params = self._extract_paging_params(
+                calldata, self.request.params
+            )
+            params.update(paging_params)
+
         return params
 
     def create_link_from_entity(
@@ -294,3 +300,25 @@ class JSONAPIEntityView:
         log.debug(
             "create_link_from_entity called, but not overridden in view class"
         )
+
+    def _extract_paging_params(self, calldata, request_params):
+        final_params = {}
+        final_params["page"] = request_params["page"]
+        final_params["page_size"] = request_params["page_size"]
+
+        self._check_paging_limit(
+            final_params["page_size"], calldata["paging"]["max_results"]
+        )
+        return final_params
+
+    def _check_paging_limit(self, page_size, max_results):
+        if int(page_size) > int(max_results):
+            raise HTTPBadRequest(
+                json={
+                    "errors": [
+                        {
+                            "title": f"Page size {page_size} is bigger than max allowed size {max_results}."
+                        }
+                    ]
+                }
+            )
